@@ -14,6 +14,7 @@ class Outputter(object):
 
     FAILED, PASSED = "FAILED", "PASSED"
     ERROR, FAIL, OK, SKIPPED = "[ERROR]", "[FAIL]", "[OK]", "[SKIPPED]"
+    UNEXPECTED_SUCCESS = "[UNEXPECTED SUCCESS]"
 
     _COLORS = [
         ("_error", "RED", ERROR),
@@ -22,6 +23,7 @@ class Outputter(object):
         ("_ok", "GREEN", OK),
         ("_passed", "GREEN", PASSED),
         ("_skipped", "BLUE", SKIPPED),
+        ("_unexpected_success", "RED", UNEXPECTED_SUCCESS),
     ]
 
     def __init__(self, colored=True, indent=" " * 2, line_width=120):
@@ -30,13 +32,10 @@ class Outputter(object):
 
         if colored:
             from colorama import Fore, Style
-            message = "{Style.BRIGHT}{color}{text}{Style.RESET_ALL}"
             for attribute, color, text in self._COLORS:
-                setattr(
-                    self, attribute, message.format(
-                        Style=Style, color=getattr(Fore, color), text=text,
-                    )
-                )
+                color = getattr(Fore, color)
+                message = f"{Style.BRIGHT}{color}{text}{Style.RESET_ALL}"
+                setattr(self, attribute, message)
         else:
             for attribute, _, text in self._COLORS:
                 setattr(self, attribute, text)
@@ -51,18 +50,14 @@ class Outputter(object):
             yield line
         yield "\n"
         yield "-" * self.line_width
-        yield "\n"
-        count = recorder.count
-        yield "Ran {count} test{s} in {runtime:.3f}s\n".format(
-            count=count, runtime=runtime, s="s" if count != 1 else "",
-        )
-        yield "\n"
+        tests = "tests" if recorder.testsRun != 1 else "test"
+        yield f"\nRan {recorder.testsRun} {tests} in {runtime:.3f}s\n\n"
         if recorder.wasSuccessful():
             yield self._passed
         else:
             yield self._failed
 
-        if recorder.count:
+        if recorder.testsRun:
             yield " ("
             summary = []
             for attribute in (
@@ -74,7 +69,7 @@ class Outputter(object):
             ):
                 subcount = len(getattr(recorder, attribute))
                 if subcount:
-                    summary.append("{0}={1}".format(attribute, subcount))
+                    summary.append(f"{attribute}={subcount}")
             yield ", ".join(summary)
             yield ")"
 
@@ -148,10 +143,23 @@ class Outputter(object):
     def test_succeeded(self, test):
         return self.format_line(test, self._ok)
 
-    def format_line(self, test, result):
-        before = "{indent}{indent}{name} ...".format(
-            indent=self.indent, name=test._testMethodName,
+    def test_unexpectedly_succeeded(self, test):
+        self._after.extend(
+            [
+                "\n",
+                "=" * self.line_width,
+                "\n",
+                self.UNEXPECTED_SUCCESS,
+                "\n",
+                fully_qualified_name(test.__class__),
+                ".",
+                test._testMethodName,
+            ],
         )
+        return self.format_line(test, self._unexpected_success)
+
+    def format_line(self, test, result):
+        before = f"{self.indent}{self.indent}{test._testMethodName} ..."
         return self._pad_center(left=before, right=result) + "\n"
 
     def _pad_center(self, left, right):
@@ -213,7 +221,7 @@ class Recorder(object):
     shouldStop = False
 
     @property
-    def count(self):
+    def testsRun(self):
         return sum(len(tests) for tests in attr.astuple(self))
 
     def startTestRun(self):
@@ -257,6 +265,10 @@ class ComponentizedReporter(object):
 
     shouldStop = False
 
+    @property
+    def testsRun(self):
+        return self.recorder.testsRun
+
     def startTestRun(self):
         self._start_time = self._time()
         self.recorder.startTestRun()
@@ -297,6 +309,12 @@ class ComponentizedReporter(object):
         self.recorder.addSuccess(test)
         self.stream.writelines(self.outputter.test_succeeded(test) or "")
 
+    def addUnexpectedSuccess(self, test):
+        self.recorder.addUnexpectedSuccess(test)
+        self.stream.writelines(
+            self.outputter.test_unexpectedly_succeeded(test) or "",
+        )
+
     def wasSuccessful(self):
         return self.recorder.wasSuccessful()
 
